<?php

namespace App\Filament\Resources;

use App\Filament\Resources\CarShowWinnerResource\Pages;
use App\Filament\Resources\CarShowWinnerResource\RelationManagers;
use App\Models\CarShowWinner;
use Filament\Forms;
use Filament\Resources\Form;
use Filament\Resources\Resource;
use Filament\Resources\Table;
use Filament\Tables;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;
use Filament\Tables\Columns\BooleanColumn;
use Filament\Tables\Columns\TextColumn;
use Filament\Forms\Components\TextInput;
use Filament\Forms\Components\Toggle;
use Filament\Forms\Components\Select;
use App\Models\Vehicles;
use App\Models\CarShowCategory;

class CarShowWinnerResource extends Resource
{
    protected static ?string $model = CarShowWinner::class;

    protected static ?string $navigationIcon = 'heroicon-o-collection';

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Select::make('vehicle')
                ->label('Vehicle')
                ->options(Vehicles::all()->pluck('owner', 'year', 'make', 'model', 'id'))
                ->searchable(),
                Select::make('category')
                ->label('Category')
                ->options(CarShowCategory::all()->pluck('category_name', 'vehicle_type', 'id'))
                ->searchable(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                TextColumn::make('awardVehicle.owner')->label('Vehicle'),
                TextColumn::make('awardCategory.category_name')->label('Category'),
                ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\DeleteBulkAction::make(),
            ]);
    }
    
    public static function getRelations(): array
    {
        return [
            //
        ];
    }
    
    public static function getPages(): array
    {
        return [
            'index' => Pages\ListCarShowWinners::route('/'),
            'create' => Pages\CreateCarShowWinner::route('/create'),
            'edit' => Pages\EditCarShowWinner::route('/{record}/edit'),
        ];
    }    
}
